mysql.result.Row_Offset

Package mysql :: Module result :: Class Row_Offset |
[hide private]
[frames] | no frames]

# Class Row_Offset

    object --+
             |
            Row_Offset

Representation of a result offset.

This is an opaque object used by the mysql.result.Result.row_tell, mysql.stmt.Statement.row_tell, mysql.result.Result.row_seek, and mysql.stmt.Statement.row_seek methods.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Instance Variables | [hide private]
`` | _offset The MYSQL_ROW_OFFSET structure (C only).

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__

Instance Variable Details | [hide private]

### _offset The MYSQL_ROW_OFFSET structure (C only).